==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-BR/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Um usuário cancelou uma requisição no website',
    'a_user_requested' => 'Um usuário requisitou um item no website',
    'accessory_name' => 'Nome do Acessório:',
    'additional_notes' => 'Comentários adicionais:',
    'admin_has_created' => 'Um administrador criou uma conta para você em :web.',
    'asset' => 'Ativo:',
    'asset_name' => 'Nome do Ativo:',
    'asset_requested' => 'Requisição de Ativo',
    'asset_tag' => 'Etiqueta de Ativo:',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Data de devolução:',
    'checkout_date' => 'Data de atribuição:',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o ativo.',
    'Confirm_Asset_Checkin' => 'Confirme a devolução do ativo',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_license_delivery' => 'Confirme a entrega de licença',
    'Confirm_asset_delivery' => 'Confirme a entrega do ativo',
    'Confirm_consumable_delivery' => 'Confirme a entrega de consumíveis',
    'current_QTY' => 'Qtde. atual',
    'Days' => 'Dias',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Data prevista de devolução:',
    'expires' => 'Expira',
    'Expiring_Assets_Report' => 'Relatório de ativos expirando.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'item' => 'Item:',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'link_to_update_password' => 'Por favor clique no link abaixo para atualizar a sua senha do :web:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'min_QTY' => 'Qtde. Min',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi feito Check-out em seu nome, detalhes abaixo.',
    'password' => 'Senha:',
    'password_reset' => 'Redefinir Senha',

    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo e clique no link na parte inferior para confirmar que leu e que concorda com os termos de uso e ter recebido o ativo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir sua senha:',
    'serial' => 'Nº de Série',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um e-mail de teste do Snipe-IT Asset Management System. Se você recebeu essa mensagem, quer dizer que o e-mail está funcionando :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'low_inventory_alert' => 'Há um :count que está abaixo do estoque mínimo ou em breve estará abaixo. | Existem :count items que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'assets_warrantee_alert' => 'Há um :count ativo com a garantia expirando nos próximos :threshold dias. | Existem :count ativos com a garantia expirando nos próximos :threshold dias.',
    'license_expiring_alert' => 'Há uma :count licença expirando nos próximos :threshold dias. | Existem :count licenças expirand nos próximos :threshold dias.',
    'to_reset' => 'Para fazer reset da senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Usuário',
    'username' => 'Nome de Usuário',
    'welcome' => 'Bem-vindo(a), :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'Accessory_Checkin_Notification' => 'Ativo verificado em',
    'Asset_Checkin_Notification' => 'Ativo verificado em',
    'License_Checkin_Notification' => 'Licença verificada em',
    'Expected_Checkin_Report' => 'Relatório de check-in de ativos esperado',
    'Expected_Checkin_Notification' => 'Lembrete: :name prazo de devolução aproximando',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'Ver seus ativos'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-BR/mail.php <==
<?php

return [
    'a_user_canceled' => 'Um usuário cancelou uma requisição no website',
    'a_user_requested' => 'Um usuário requisitou um item no website',
    'accessory_name' => 'Nome do Acessório:',
    'additional_notes' => 'Comentários adicionais:',
    'admin_has_created' => 'Um administrador criou uma conta para você em :web.',
    'asset' => 'Ativo:',
    'asset_name' => 'Nome do Ativo:',
    'asset_requested' => 'Requisição de Ativo',
    'asset_tag' => 'Etiqueta de Ativo',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente,',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Data de devolução:',
    'checkout_date' => 'Data de atribuição:',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o ativo.',
    'Confirm_Asset_Checkin' => 'Confirme a devolução do ativo',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_license_delivery' => 'Confirme a entrega de licença',
    'Confirm_asset_delivery' => 'Confirme a entrega do ativo',
    'Confirm_consumable_delivery' => 'Confirme a entrega de consumíveis',
    'current_QTY' => 'Qtde. atual',
    'Days' => 'Dias',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Data prevista de devolução:',
    'expires' => 'Expira',
    'Expiring_Assets_Report' => 'Relatório de ativos expirando.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'item' => 'Item:',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'link_to_update_password' => 'Por favor clique no link abaixo para atualizar a sua senha do :web:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'min_QTY' => 'Qtde. Min',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi feito Check-out em seu nome, detalhes abaixo.',
    'password' => 'Senha:',
    'password_reset' => 'Redefinir Senha',

    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo e clique no link na parte inferior para confirmar que leu e que concorda com os termos de uso e ter recebido o ativo.',
    'requested' => 'Solicitado:',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir sua senha:',
    'serial' => 'Nº de Série',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um e-mail de teste do Snipe-IT Asset Management System. Se você recebeu essa mensagem, quer dizer que o e-mail está funcionando :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'low_inventory_alert' => 'Há um :count que está abaixo do estoque mínimo ou em breve estará abaixo. | Existem :count items que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'Há uma :count licença expirando nos próximos :threshold dias. | Existem :count licenças expirand nos próximos :threshold dias.',
    'to_reset' => 'Para fazer reset da senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Existe um :count ativo que está sendo auditado dentro de :threshold days. There are :count assets que estão sendo enviados para auditoria dentro de :threshold dias.',
    'user' => 'Usuário',
    'username' => 'Nome de Usuário',
    'welcome' => 'Bem-vindo(a), :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'Accessory_Checkin_Notification' => 'Ativo verificado em',
    'Asset_Checkin_Notification' => 'Ativo verificado em',
    'License_Checkin_Notification' => 'Licença verificada em',
    'Expected_Checkin_Report' => 'Relatório de check-in de ativos esperado',
    'Expected_Checkin_Notification' => 'Lembrete: :name prazo de devolução aproximando',
    'Expected_Checkin_Date' => 'Um ativo com check-out para você deve ser verificado novamente em :date',
    'your_assets' => 'Ver seus ativos',
];
